/*
 * Redigera denna fil och spara den som userContent.css i mappen "chrome"
 * i din profilmapp.
 */

/*
 * Denna fil kan användas till att anpassa stilen på webbsidor du besöker.
 * Regler utan tillägget "!important" åsidosätts av eventuella regler som
 * webbsidans skapare har angivit. Regler med "!important" åsidosätter
 * skaparens regler.
 */

/*
 * Exempel: Stäng av elementet "blink" från att blinka
 *
 * blink { text-decoration: none ! important; }
 *
 */

/*
 * Exempel: Ge alla tabeller en bård på 2 pixlar
 *
 * table { border: 2px solid; }
 */

/*
 * Exempel: Stäng av elementet "marquee"
 *
 * marquee { -moz-binding: none; }
 *
 */
 
/* 
 * För fler exempel, se http://www.mozilla.org/unix/customizing.html
 */

